==> keepassx_0.2.2.orig.tar.gz: keepassx-0.2.2/src/dialogs/AboutDlg.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Tarek Saidi                                     *
 *   tarek@linux                                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _ABOUTDIALOG_H_
#define _ABOUTDIALOG_H_
#include "ui_AboutDlg.h"
#include "lib/UrlLabel.h"
#include "main.h"



class CAboutDialog : public QDialog, public Ui_AboutDlg
{
  Q_OBJECT
public:
  CAboutDialog(QWidget* parent = 0,  bool modal = FALSE, Qt::WFlags fl = 0 );
  ~CAboutDialog();

public slots:
    virtual void OnClose();
    void OnHomepageClicked();
    void OnEMailClicked();
private:
	inline void loadLicFromFile();
};

#endif

==> keepassx_0.4.3+dfsg.orig.tar.gz: keepassx-0.4.3/src/dialogs/AboutDlg.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Tarek Saidi                                *
 *   tarek.saidi@arcor.de                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2 of the License.               *

 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _ABOUTDIALOG_H_
#define _ABOUTDIALOG_H_

#include "ui_AboutDlg.h"

class AboutDialog : public QDialog, private Ui_AboutDlg
{
	Q_OBJECT

	public:
		AboutDialog(QWidget* parent);

	private:
		QPixmap BannerPixmap;
		virtual void paintEvent(QPaintEvent*);
};

#endif
